# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
RWStepAP203 module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_rwstepap203.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _RWStepAP203
else:
    import _RWStepAP203

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _RWStepAP203.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _RWStepAP203.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _RWStepAP203.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _RWStepAP203.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _RWStepAP203.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _RWStepAP203.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _RWStepAP203.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _RWStepAP203.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _RWStepAP203.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _RWStepAP203.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _RWStepAP203.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _RWStepAP203.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _RWStepAP203.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _RWStepAP203.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _RWStepAP203.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _RWStepAP203.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _RWStepAP203.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _RWStepAP203:
_RWStepAP203.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _RWStepAP203.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.StepData
import OCC.Core.Interface
import OCC.Core.TCollection
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.MoniTool
import OCC.Core.TopoDS
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.Resource
import OCC.Core.StepAP203
import OCC.Core.StepBasic
import OCC.Core.StepRepr

from enum import IntEnum
from OCC.Core.Exception import *



class RWStepAP203_RWCcDesignApproval(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepAP203.RWStepAP203_RWCcDesignApproval_swiginit(self, _RWStepAP203.new_RWStepAP203_RWCcDesignApproval(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads ccdesignapproval.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP203_CcDesignApproval

        Returns
        -------
        None

        """
        return _RWStepAP203.RWStepAP203_RWCcDesignApproval_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepAP203_CcDesignApproval
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP203.RWStepAP203_RWCcDesignApproval_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes ccdesignapproval.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP203_CcDesignApproval

        Returns
        -------
        None

        """
        return _RWStepAP203.RWStepAP203_RWCcDesignApproval_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP203.delete_RWStepAP203_RWCcDesignApproval

# Register RWStepAP203_RWCcDesignApproval in _RWStepAP203:
_RWStepAP203.RWStepAP203_RWCcDesignApproval_swigregister(RWStepAP203_RWCcDesignApproval)

class RWStepAP203_RWCcDesignCertification(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepAP203.RWStepAP203_RWCcDesignCertification_swiginit(self, _RWStepAP203.new_RWStepAP203_RWCcDesignCertification(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads ccdesigncertification.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP203_CcDesignCertification

        Returns
        -------
        None

        """
        return _RWStepAP203.RWStepAP203_RWCcDesignCertification_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepAP203_CcDesignCertification
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP203.RWStepAP203_RWCcDesignCertification_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes ccdesigncertification.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP203_CcDesignCertification

        Returns
        -------
        None

        """
        return _RWStepAP203.RWStepAP203_RWCcDesignCertification_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP203.delete_RWStepAP203_RWCcDesignCertification

# Register RWStepAP203_RWCcDesignCertification in _RWStepAP203:
_RWStepAP203.RWStepAP203_RWCcDesignCertification_swigregister(RWStepAP203_RWCcDesignCertification)

class RWStepAP203_RWCcDesignContract(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepAP203.RWStepAP203_RWCcDesignContract_swiginit(self, _RWStepAP203.new_RWStepAP203_RWCcDesignContract(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads ccdesigncontract.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP203_CcDesignContract

        Returns
        -------
        None

        """
        return _RWStepAP203.RWStepAP203_RWCcDesignContract_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepAP203_CcDesignContract
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP203.RWStepAP203_RWCcDesignContract_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes ccdesigncontract.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP203_CcDesignContract

        Returns
        -------
        None

        """
        return _RWStepAP203.RWStepAP203_RWCcDesignContract_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP203.delete_RWStepAP203_RWCcDesignContract

# Register RWStepAP203_RWCcDesignContract in _RWStepAP203:
_RWStepAP203.RWStepAP203_RWCcDesignContract_swigregister(RWStepAP203_RWCcDesignContract)

class RWStepAP203_RWCcDesignDateAndTimeAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepAP203.RWStepAP203_RWCcDesignDateAndTimeAssignment_swiginit(self, _RWStepAP203.new_RWStepAP203_RWCcDesignDateAndTimeAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads ccdesigndateandtimeassignment.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP203_CcDesignDateAndTimeAssignment

        Returns
        -------
        None

        """
        return _RWStepAP203.RWStepAP203_RWCcDesignDateAndTimeAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepAP203_CcDesignDateAndTimeAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP203.RWStepAP203_RWCcDesignDateAndTimeAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes ccdesigndateandtimeassignment.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP203_CcDesignDateAndTimeAssignment

        Returns
        -------
        None

        """
        return _RWStepAP203.RWStepAP203_RWCcDesignDateAndTimeAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP203.delete_RWStepAP203_RWCcDesignDateAndTimeAssignment

# Register RWStepAP203_RWCcDesignDateAndTimeAssignment in _RWStepAP203:
_RWStepAP203.RWStepAP203_RWCcDesignDateAndTimeAssignment_swigregister(RWStepAP203_RWCcDesignDateAndTimeAssignment)

class RWStepAP203_RWCcDesignPersonAndOrganizationAssignment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepAP203.RWStepAP203_RWCcDesignPersonAndOrganizationAssignment_swiginit(self, _RWStepAP203.new_RWStepAP203_RWCcDesignPersonAndOrganizationAssignment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads ccdesignpersonandorganizationassignment.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP203_CcDesignPersonAndOrganizationAssignment

        Returns
        -------
        None

        """
        return _RWStepAP203.RWStepAP203_RWCcDesignPersonAndOrganizationAssignment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepAP203_CcDesignPersonAndOrganizationAssignment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP203.RWStepAP203_RWCcDesignPersonAndOrganizationAssignment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes ccdesignpersonandorganizationassignment.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP203_CcDesignPersonAndOrganizationAssignment

        Returns
        -------
        None

        """
        return _RWStepAP203.RWStepAP203_RWCcDesignPersonAndOrganizationAssignment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP203.delete_RWStepAP203_RWCcDesignPersonAndOrganizationAssignment

# Register RWStepAP203_RWCcDesignPersonAndOrganizationAssignment in _RWStepAP203:
_RWStepAP203.RWStepAP203_RWCcDesignPersonAndOrganizationAssignment_swigregister(RWStepAP203_RWCcDesignPersonAndOrganizationAssignment)

class RWStepAP203_RWCcDesignSecurityClassification(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepAP203.RWStepAP203_RWCcDesignSecurityClassification_swiginit(self, _RWStepAP203.new_RWStepAP203_RWCcDesignSecurityClassification(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads ccdesignsecurityclassification.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP203_CcDesignSecurityClassification

        Returns
        -------
        None

        """
        return _RWStepAP203.RWStepAP203_RWCcDesignSecurityClassification_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepAP203_CcDesignSecurityClassification
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP203.RWStepAP203_RWCcDesignSecurityClassification_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes ccdesignsecurityclassification.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP203_CcDesignSecurityClassification

        Returns
        -------
        None

        """
        return _RWStepAP203.RWStepAP203_RWCcDesignSecurityClassification_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP203.delete_RWStepAP203_RWCcDesignSecurityClassification

# Register RWStepAP203_RWCcDesignSecurityClassification in _RWStepAP203:
_RWStepAP203.RWStepAP203_RWCcDesignSecurityClassification_swigregister(RWStepAP203_RWCcDesignSecurityClassification)

class RWStepAP203_RWCcDesignSpecificationReference(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepAP203.RWStepAP203_RWCcDesignSpecificationReference_swiginit(self, _RWStepAP203.new_RWStepAP203_RWCcDesignSpecificationReference(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads ccdesignspecificationreference.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP203_CcDesignSpecificationReference

        Returns
        -------
        None

        """
        return _RWStepAP203.RWStepAP203_RWCcDesignSpecificationReference_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepAP203_CcDesignSpecificationReference
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP203.RWStepAP203_RWCcDesignSpecificationReference_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes ccdesignspecificationreference.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP203_CcDesignSpecificationReference

        Returns
        -------
        None

        """
        return _RWStepAP203.RWStepAP203_RWCcDesignSpecificationReference_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP203.delete_RWStepAP203_RWCcDesignSpecificationReference

# Register RWStepAP203_RWCcDesignSpecificationReference in _RWStepAP203:
_RWStepAP203.RWStepAP203_RWCcDesignSpecificationReference_swigregister(RWStepAP203_RWCcDesignSpecificationReference)

class RWStepAP203_RWChange(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepAP203.RWStepAP203_RWChange_swiginit(self, _RWStepAP203.new_RWStepAP203_RWChange(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads change.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP203_Change

        Returns
        -------
        None

        """
        return _RWStepAP203.RWStepAP203_RWChange_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepAP203_Change
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP203.RWStepAP203_RWChange_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes change.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP203_Change

        Returns
        -------
        None

        """
        return _RWStepAP203.RWStepAP203_RWChange_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP203.delete_RWStepAP203_RWChange

# Register RWStepAP203_RWChange in _RWStepAP203:
_RWStepAP203.RWStepAP203_RWChange_swigregister(RWStepAP203_RWChange)

class RWStepAP203_RWChangeRequest(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepAP203.RWStepAP203_RWChangeRequest_swiginit(self, _RWStepAP203.new_RWStepAP203_RWChangeRequest(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads changerequest.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP203_ChangeRequest

        Returns
        -------
        None

        """
        return _RWStepAP203.RWStepAP203_RWChangeRequest_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepAP203_ChangeRequest
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP203.RWStepAP203_RWChangeRequest_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes changerequest.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP203_ChangeRequest

        Returns
        -------
        None

        """
        return _RWStepAP203.RWStepAP203_RWChangeRequest_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP203.delete_RWStepAP203_RWChangeRequest

# Register RWStepAP203_RWChangeRequest in _RWStepAP203:
_RWStepAP203.RWStepAP203_RWChangeRequest_swigregister(RWStepAP203_RWChangeRequest)

class RWStepAP203_RWStartRequest(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepAP203.RWStepAP203_RWStartRequest_swiginit(self, _RWStepAP203.new_RWStepAP203_RWStartRequest(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads startrequest.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP203_StartRequest

        Returns
        -------
        None

        """
        return _RWStepAP203.RWStepAP203_RWStartRequest_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepAP203_StartRequest
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP203.RWStepAP203_RWStartRequest_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes startrequest.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP203_StartRequest

        Returns
        -------
        None

        """
        return _RWStepAP203.RWStepAP203_RWStartRequest_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP203.delete_RWStepAP203_RWStartRequest

# Register RWStepAP203_RWStartRequest in _RWStepAP203:
_RWStepAP203.RWStepAP203_RWStartRequest_swigregister(RWStepAP203_RWStartRequest)

class RWStepAP203_RWStartWork(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepAP203.RWStepAP203_RWStartWork_swiginit(self, _RWStepAP203.new_RWStepAP203_RWStartWork(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads startwork.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepAP203_StartWork

        Returns
        -------
        None

        """
        return _RWStepAP203.RWStepAP203_RWStartWork_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepAP203_StartWork
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepAP203.RWStepAP203_RWStartWork_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes startwork.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepAP203_StartWork

        Returns
        -------
        None

        """
        return _RWStepAP203.RWStepAP203_RWStartWork_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepAP203.delete_RWStepAP203_RWStartWork

# Register RWStepAP203_RWStartWork in _RWStepAP203:
_RWStepAP203.RWStepAP203_RWStartWork_swigregister(RWStepAP203_RWStartWork)








# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
RWStepDimTol module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_rwstepdimtol.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _RWStepDimTol
else:
    import _RWStepDimTol

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _RWStepDimTol.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _RWStepDimTol.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _RWStepDimTol.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _RWStepDimTol.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _RWStepDimTol.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _RWStepDimTol.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _RWStepDimTol.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _RWStepDimTol.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _RWStepDimTol.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _RWStepDimTol.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _RWStepDimTol.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _RWStepDimTol.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _RWStepDimTol.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _RWStepDimTol.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _RWStepDimTol.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _RWStepDimTol.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _RWStepDimTol.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _RWStepDimTol:
_RWStepDimTol.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _RWStepDimTol.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.StepData
import OCC.Core.Interface
import OCC.Core.TCollection
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.MoniTool
import OCC.Core.TopoDS
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.Resource
import OCC.Core.StepDimTol
import OCC.Core.StepRepr
import OCC.Core.StepBasic
import OCC.Core.StepShape
import OCC.Core.StepGeom

from enum import IntEnum
from OCC.Core.Exception import *



class RWStepDimTol_RWAngularityTolerance(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWAngularityTolerance_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWAngularityTolerance(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads angularitytolerance.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_AngularityTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWAngularityTolerance_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_AngularityTolerance
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWAngularityTolerance_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes angularitytolerance.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_AngularityTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWAngularityTolerance_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWAngularityTolerance

# Register RWStepDimTol_RWAngularityTolerance in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWAngularityTolerance_swigregister(RWStepDimTol_RWAngularityTolerance)

class RWStepDimTol_RWCircularRunoutTolerance(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWCircularRunoutTolerance_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWCircularRunoutTolerance(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads circularrunouttolerance.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_CircularRunoutTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWCircularRunoutTolerance_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_CircularRunoutTolerance
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWCircularRunoutTolerance_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes circularrunouttolerance.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_CircularRunoutTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWCircularRunoutTolerance_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWCircularRunoutTolerance

# Register RWStepDimTol_RWCircularRunoutTolerance in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWCircularRunoutTolerance_swigregister(RWStepDimTol_RWCircularRunoutTolerance)

class RWStepDimTol_RWCoaxialityTolerance(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWCoaxialityTolerance_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWCoaxialityTolerance(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads coaxialitytolerance.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_CoaxialityTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWCoaxialityTolerance_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_CoaxialityTolerance
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWCoaxialityTolerance_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes coaxialitytolerance.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_CoaxialityTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWCoaxialityTolerance_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWCoaxialityTolerance

# Register RWStepDimTol_RWCoaxialityTolerance in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWCoaxialityTolerance_swigregister(RWStepDimTol_RWCoaxialityTolerance)

class RWStepDimTol_RWCommonDatum(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWCommonDatum_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWCommonDatum(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads commondatum.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_CommonDatum

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWCommonDatum_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_CommonDatum
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWCommonDatum_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes commondatum.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_CommonDatum

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWCommonDatum_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWCommonDatum

# Register RWStepDimTol_RWCommonDatum in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWCommonDatum_swigregister(RWStepDimTol_RWCommonDatum)

class RWStepDimTol_RWConcentricityTolerance(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWConcentricityTolerance_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWConcentricityTolerance(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads concentricitytolerance.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_ConcentricityTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWConcentricityTolerance_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_ConcentricityTolerance
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWConcentricityTolerance_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes concentricitytolerance.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_ConcentricityTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWConcentricityTolerance_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWConcentricityTolerance

# Register RWStepDimTol_RWConcentricityTolerance in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWConcentricityTolerance_swigregister(RWStepDimTol_RWConcentricityTolerance)

class RWStepDimTol_RWCylindricityTolerance(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWCylindricityTolerance_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWCylindricityTolerance(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads cylindricitytolerance.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_CylindricityTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWCylindricityTolerance_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_CylindricityTolerance
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWCylindricityTolerance_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes cylindricitytolerance.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_CylindricityTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWCylindricityTolerance_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWCylindricityTolerance

# Register RWStepDimTol_RWCylindricityTolerance in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWCylindricityTolerance_swigregister(RWStepDimTol_RWCylindricityTolerance)

class RWStepDimTol_RWDatum(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWDatum_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWDatum(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads datum.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_Datum

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWDatum_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_Datum
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWDatum_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes datum.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_Datum

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWDatum_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWDatum

# Register RWStepDimTol_RWDatum in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWDatum_swigregister(RWStepDimTol_RWDatum)

class RWStepDimTol_RWDatumFeature(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWDatumFeature_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWDatumFeature(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads datumfeature.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_DatumFeature

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWDatumFeature_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_DatumFeature
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWDatumFeature_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes datumfeature.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_DatumFeature

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWDatumFeature_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWDatumFeature

# Register RWStepDimTol_RWDatumFeature in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWDatumFeature_swigregister(RWStepDimTol_RWDatumFeature)

class RWStepDimTol_RWDatumReference(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWDatumReference_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWDatumReference(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads datumreference.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_DatumReference

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWDatumReference_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_DatumReference
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWDatumReference_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes datumreference.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_DatumReference

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWDatumReference_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWDatumReference

# Register RWStepDimTol_RWDatumReference in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWDatumReference_swigregister(RWStepDimTol_RWDatumReference)

class RWStepDimTol_RWDatumReferenceCompartment(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWDatumReferenceCompartment_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWDatumReferenceCompartment(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads datumreferenceelement.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_DatumReferenceCompartment

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWDatumReferenceCompartment_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_DatumReferenceCompartment
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWDatumReferenceCompartment_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes datumreferenceelement.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_DatumReferenceCompartment

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWDatumReferenceCompartment_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWDatumReferenceCompartment

# Register RWStepDimTol_RWDatumReferenceCompartment in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWDatumReferenceCompartment_swigregister(RWStepDimTol_RWDatumReferenceCompartment)

class RWStepDimTol_RWDatumReferenceElement(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWDatumReferenceElement_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWDatumReferenceElement(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads datumreferenceelement.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_DatumReferenceElement

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWDatumReferenceElement_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_DatumReferenceElement
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWDatumReferenceElement_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes datumreferenceelement.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_DatumReferenceElement

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWDatumReferenceElement_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWDatumReferenceElement

# Register RWStepDimTol_RWDatumReferenceElement in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWDatumReferenceElement_swigregister(RWStepDimTol_RWDatumReferenceElement)

class RWStepDimTol_RWDatumReferenceModifierWithValue(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWDatumReferenceModifierWithValue_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWDatumReferenceModifierWithValue(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads datumreferencemodifierwithvalue.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_DatumReferenceModifierWithValue

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWDatumReferenceModifierWithValue_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes datumreferencemodifierwithvalue.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_DatumReferenceModifierWithValue

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWDatumReferenceModifierWithValue_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWDatumReferenceModifierWithValue

# Register RWStepDimTol_RWDatumReferenceModifierWithValue in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWDatumReferenceModifierWithValue_swigregister(RWStepDimTol_RWDatumReferenceModifierWithValue)

class RWStepDimTol_RWDatumSystem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWDatumSystem_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWDatumSystem(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads datumsystem.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_DatumSystem

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWDatumSystem_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_DatumSystem
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWDatumSystem_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes datumsystem.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_DatumSystem

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWDatumSystem_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWDatumSystem

# Register RWStepDimTol_RWDatumSystem in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWDatumSystem_swigregister(RWStepDimTol_RWDatumSystem)

class RWStepDimTol_RWDatumTarget(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWDatumTarget_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWDatumTarget(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads datumtarget.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_DatumTarget

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWDatumTarget_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_DatumTarget
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWDatumTarget_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes datumtarget.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_DatumTarget

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWDatumTarget_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWDatumTarget

# Register RWStepDimTol_RWDatumTarget in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWDatumTarget_swigregister(RWStepDimTol_RWDatumTarget)

class RWStepDimTol_RWFlatnessTolerance(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWFlatnessTolerance_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWFlatnessTolerance(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads flatnesstolerance.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_FlatnessTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWFlatnessTolerance_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_FlatnessTolerance
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWFlatnessTolerance_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes flatnesstolerance.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_FlatnessTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWFlatnessTolerance_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWFlatnessTolerance

# Register RWStepDimTol_RWFlatnessTolerance in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWFlatnessTolerance_swigregister(RWStepDimTol_RWFlatnessTolerance)

class RWStepDimTol_RWGeneralDatumReference(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWGeneralDatumReference_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWGeneralDatumReference(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads generaldatumreference.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_GeneralDatumReference

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeneralDatumReference_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_GeneralDatumReference
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeneralDatumReference_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes generaldatumreference.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_GeneralDatumReference

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeneralDatumReference_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWGeneralDatumReference

# Register RWStepDimTol_RWGeneralDatumReference in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWGeneralDatumReference_swigregister(RWStepDimTol_RWGeneralDatumReference)

class RWStepDimTol_RWGeoTolAndGeoTolWthDatRef(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthDatRef_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWGeoTolAndGeoTolWthDatRef(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_GeoTolAndGeoTolWthDatRef

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthDatRef_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepDimTol_GeoTolAndGeoTolWthDatRef
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthDatRef_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_GeoTolAndGeoTolWthDatRef

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthDatRef_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWGeoTolAndGeoTolWthDatRef

# Register RWStepDimTol_RWGeoTolAndGeoTolWthDatRef in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthDatRef_swigregister(RWStepDimTol_RWGeoTolAndGeoTolWthDatRef)

class RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndGeoTolWthMaxTol(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndGeoTolWthMaxTol_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndGeoTolWthMaxTol(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_GeoTolAndGeoTolWthDatRefAndGeoTolWthMaxTol

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndGeoTolWthMaxTol_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepDimTol_GeoTolAndGeoTolWthDatRefAndGeoTolWthMaxTol
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndGeoTolWthMaxTol_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_GeoTolAndGeoTolWthDatRefAndGeoTolWthMaxTol

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndGeoTolWthMaxTol_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndGeoTolWthMaxTol

# Register RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndGeoTolWthMaxTol in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndGeoTolWthMaxTol_swigregister(RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndGeoTolWthMaxTol)

class RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndGeoTolWthMod(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndGeoTolWthMod_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndGeoTolWthMod(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_GeoTolAndGeoTolWthDatRefAndGeoTolWthMod

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndGeoTolWthMod_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepDimTol_GeoTolAndGeoTolWthDatRefAndGeoTolWthMod
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndGeoTolWthMod_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_GeoTolAndGeoTolWthDatRefAndGeoTolWthMod

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndGeoTolWthMod_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndGeoTolWthMod

# Register RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndGeoTolWthMod in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndGeoTolWthMod_swigregister(RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndGeoTolWthMod)

class RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndModGeoTolAndPosTol(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndModGeoTolAndPosTol_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndModGeoTolAndPosTol(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_GeoTolAndGeoTolWthDatRefAndModGeoTolAndPosTol

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndModGeoTolAndPosTol_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepDimTol_GeoTolAndGeoTolWthDatRefAndModGeoTolAndPosTol
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndModGeoTolAndPosTol_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_GeoTolAndGeoTolWthDatRefAndModGeoTolAndPosTol

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndModGeoTolAndPosTol_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndModGeoTolAndPosTol

# Register RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndModGeoTolAndPosTol in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndModGeoTolAndPosTol_swigregister(RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndModGeoTolAndPosTol)

class RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndUneqDisGeoTol(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndUneqDisGeoTol_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndUneqDisGeoTol(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_GeoTolAndGeoTolWthDatRefAndUneqDisGeoTol

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndUneqDisGeoTol_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepDimTol_GeoTolAndGeoTolWthDatRefAndUneqDisGeoTol
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndUneqDisGeoTol_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_GeoTolAndGeoTolWthDatRefAndUneqDisGeoTol

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndUneqDisGeoTol_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndUneqDisGeoTol

# Register RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndUneqDisGeoTol in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndUneqDisGeoTol_swigregister(RWStepDimTol_RWGeoTolAndGeoTolWthDatRefAndUneqDisGeoTol)

class RWStepDimTol_RWGeoTolAndGeoTolWthMaxTol(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthMaxTol_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWGeoTolAndGeoTolWthMaxTol(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_GeoTolAndGeoTolWthMaxTol

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthMaxTol_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepDimTol_GeoTolAndGeoTolWthMaxTol
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthMaxTol_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_GeoTolAndGeoTolWthMaxTol

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthMaxTol_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWGeoTolAndGeoTolWthMaxTol

# Register RWStepDimTol_RWGeoTolAndGeoTolWthMaxTol in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthMaxTol_swigregister(RWStepDimTol_RWGeoTolAndGeoTolWthMaxTol)

class RWStepDimTol_RWGeoTolAndGeoTolWthMod(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        No available documentation.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthMod_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWGeoTolAndGeoTolWthMod(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_GeoTolAndGeoTolWthMod

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthMod_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        ent: StepDimTol_GeoTolAndGeoTolWthMod
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthMod_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        No available documentation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_GeoTolAndGeoTolWthMod

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthMod_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWGeoTolAndGeoTolWthMod

# Register RWStepDimTol_RWGeoTolAndGeoTolWthMod in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWGeoTolAndGeoTolWthMod_swigregister(RWStepDimTol_RWGeoTolAndGeoTolWthMod)

class RWStepDimTol_RWGeometricTolerance(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWGeometricTolerance_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWGeometricTolerance(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads geometrictolerance.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_GeometricTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeometricTolerance_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_GeometricTolerance
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeometricTolerance_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes geometrictolerance.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_GeometricTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeometricTolerance_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWGeometricTolerance

# Register RWStepDimTol_RWGeometricTolerance in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWGeometricTolerance_swigregister(RWStepDimTol_RWGeometricTolerance)

class RWStepDimTol_RWGeometricToleranceRelationship(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWGeometricToleranceRelationship_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWGeometricToleranceRelationship(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads geometrictolerancerelationship.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_GeometricToleranceRelationship

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeometricToleranceRelationship_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_GeometricToleranceRelationship
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeometricToleranceRelationship_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes geometrictolerancerelationship.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_GeometricToleranceRelationship

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeometricToleranceRelationship_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWGeometricToleranceRelationship

# Register RWStepDimTol_RWGeometricToleranceRelationship in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWGeometricToleranceRelationship_swigregister(RWStepDimTol_RWGeometricToleranceRelationship)

class RWStepDimTol_RWGeometricToleranceWithDatumReference(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWGeometricToleranceWithDatumReference_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWGeometricToleranceWithDatumReference(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads geometrictolerancewithdatumreference.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_GeometricToleranceWithDatumReference

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeometricToleranceWithDatumReference_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_GeometricToleranceWithDatumReference
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeometricToleranceWithDatumReference_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes geometrictolerancewithdatumreference.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_GeometricToleranceWithDatumReference

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeometricToleranceWithDatumReference_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWGeometricToleranceWithDatumReference

# Register RWStepDimTol_RWGeometricToleranceWithDatumReference in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWGeometricToleranceWithDatumReference_swigregister(RWStepDimTol_RWGeometricToleranceWithDatumReference)

class RWStepDimTol_RWGeometricToleranceWithDefinedAreaUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWGeometricToleranceWithDefinedAreaUnit_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWGeometricToleranceWithDefinedAreaUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads geometrictolerancewithdefinedareaunit.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_GeometricToleranceWithDefinedAreaUnit

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeometricToleranceWithDefinedAreaUnit_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_GeometricToleranceWithDefinedAreaUnit
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeometricToleranceWithDefinedAreaUnit_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes geometrictolerancewithdefinedareaunit.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_GeometricToleranceWithDefinedAreaUnit

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeometricToleranceWithDefinedAreaUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWGeometricToleranceWithDefinedAreaUnit

# Register RWStepDimTol_RWGeometricToleranceWithDefinedAreaUnit in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWGeometricToleranceWithDefinedAreaUnit_swigregister(RWStepDimTol_RWGeometricToleranceWithDefinedAreaUnit)

class RWStepDimTol_RWGeometricToleranceWithDefinedUnit(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWGeometricToleranceWithDefinedUnit_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWGeometricToleranceWithDefinedUnit(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads geometrictolerancewithdefinedunit.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_GeometricToleranceWithDefinedUnit

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeometricToleranceWithDefinedUnit_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_GeometricToleranceWithDefinedUnit
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeometricToleranceWithDefinedUnit_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes geometrictolerancewithdefinedunit.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_GeometricToleranceWithDefinedUnit

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeometricToleranceWithDefinedUnit_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWGeometricToleranceWithDefinedUnit

# Register RWStepDimTol_RWGeometricToleranceWithDefinedUnit in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWGeometricToleranceWithDefinedUnit_swigregister(RWStepDimTol_RWGeometricToleranceWithDefinedUnit)

class RWStepDimTol_RWGeometricToleranceWithMaximumTolerance(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWGeometricToleranceWithMaximumTolerance_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWGeometricToleranceWithMaximumTolerance(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads geometrictolerancewithmaximumtolerance.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_GeometricToleranceWithMaximumTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeometricToleranceWithMaximumTolerance_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_GeometricToleranceWithMaximumTolerance
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeometricToleranceWithMaximumTolerance_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes geometrictolerancewithmaximumtolerance.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_GeometricToleranceWithMaximumTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeometricToleranceWithMaximumTolerance_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWGeometricToleranceWithMaximumTolerance

# Register RWStepDimTol_RWGeometricToleranceWithMaximumTolerance in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWGeometricToleranceWithMaximumTolerance_swigregister(RWStepDimTol_RWGeometricToleranceWithMaximumTolerance)

class RWStepDimTol_RWGeometricToleranceWithModifiers(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWGeometricToleranceWithModifiers_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWGeometricToleranceWithModifiers(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads geometrictolerancewithmodifiers.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_GeometricToleranceWithModifiers

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeometricToleranceWithModifiers_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_GeometricToleranceWithModifiers
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeometricToleranceWithModifiers_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes geometrictolerancewithmodifiers.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_GeometricToleranceWithModifiers

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWGeometricToleranceWithModifiers_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWGeometricToleranceWithModifiers

# Register RWStepDimTol_RWGeometricToleranceWithModifiers in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWGeometricToleranceWithModifiers_swigregister(RWStepDimTol_RWGeometricToleranceWithModifiers)

class RWStepDimTol_RWLineProfileTolerance(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWLineProfileTolerance_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWLineProfileTolerance(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads lineprofiletolerance.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_LineProfileTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWLineProfileTolerance_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_LineProfileTolerance
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWLineProfileTolerance_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes lineprofiletolerance.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_LineProfileTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWLineProfileTolerance_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWLineProfileTolerance

# Register RWStepDimTol_RWLineProfileTolerance in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWLineProfileTolerance_swigregister(RWStepDimTol_RWLineProfileTolerance)

class RWStepDimTol_RWModifiedGeometricTolerance(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWModifiedGeometricTolerance_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWModifiedGeometricTolerance(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads modifiedgeometrictolerance.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_ModifiedGeometricTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWModifiedGeometricTolerance_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_ModifiedGeometricTolerance
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWModifiedGeometricTolerance_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes modifiedgeometrictolerance.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_ModifiedGeometricTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWModifiedGeometricTolerance_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWModifiedGeometricTolerance

# Register RWStepDimTol_RWModifiedGeometricTolerance in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWModifiedGeometricTolerance_swigregister(RWStepDimTol_RWModifiedGeometricTolerance)

class RWStepDimTol_RWNonUniformZoneDefinition(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWNonUniformZoneDefinition_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWNonUniformZoneDefinition(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads nonuniformzonedefinition.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_NonUniformZoneDefinition

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWNonUniformZoneDefinition_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_NonUniformZoneDefinition
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWNonUniformZoneDefinition_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes nonuniformzonedefinition.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_NonUniformZoneDefinition

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWNonUniformZoneDefinition_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWNonUniformZoneDefinition

# Register RWStepDimTol_RWNonUniformZoneDefinition in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWNonUniformZoneDefinition_swigregister(RWStepDimTol_RWNonUniformZoneDefinition)

class RWStepDimTol_RWParallelismTolerance(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWParallelismTolerance_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWParallelismTolerance(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads parallelismtolerance.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_ParallelismTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWParallelismTolerance_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_ParallelismTolerance
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWParallelismTolerance_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes parallelismtolerance.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_ParallelismTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWParallelismTolerance_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWParallelismTolerance

# Register RWStepDimTol_RWParallelismTolerance in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWParallelismTolerance_swigregister(RWStepDimTol_RWParallelismTolerance)

class RWStepDimTol_RWPerpendicularityTolerance(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWPerpendicularityTolerance_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWPerpendicularityTolerance(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads perpendicularitytolerance.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_PerpendicularityTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWPerpendicularityTolerance_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_PerpendicularityTolerance
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWPerpendicularityTolerance_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes perpendicularitytolerance.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_PerpendicularityTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWPerpendicularityTolerance_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWPerpendicularityTolerance

# Register RWStepDimTol_RWPerpendicularityTolerance in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWPerpendicularityTolerance_swigregister(RWStepDimTol_RWPerpendicularityTolerance)

class RWStepDimTol_RWPlacedDatumTargetFeature(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWPlacedDatumTargetFeature_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWPlacedDatumTargetFeature(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads placeddatumtargetfeature.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_PlacedDatumTargetFeature

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWPlacedDatumTargetFeature_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_PlacedDatumTargetFeature
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWPlacedDatumTargetFeature_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes placeddatumtargetfeature.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_PlacedDatumTargetFeature

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWPlacedDatumTargetFeature_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWPlacedDatumTargetFeature

# Register RWStepDimTol_RWPlacedDatumTargetFeature in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWPlacedDatumTargetFeature_swigregister(RWStepDimTol_RWPlacedDatumTargetFeature)

class RWStepDimTol_RWPositionTolerance(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWPositionTolerance_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWPositionTolerance(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads positiontolerance.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_PositionTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWPositionTolerance_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_PositionTolerance
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWPositionTolerance_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes positiontolerance.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_PositionTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWPositionTolerance_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWPositionTolerance

# Register RWStepDimTol_RWPositionTolerance in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWPositionTolerance_swigregister(RWStepDimTol_RWPositionTolerance)

class RWStepDimTol_RWProjectedZoneDefinition(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWProjectedZoneDefinition_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWProjectedZoneDefinition(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads projectedzonedefinition.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_ProjectedZoneDefinition

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWProjectedZoneDefinition_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_ProjectedZoneDefinition
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWProjectedZoneDefinition_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes projectedzonedefinition.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_ProjectedZoneDefinition

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWProjectedZoneDefinition_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWProjectedZoneDefinition

# Register RWStepDimTol_RWProjectedZoneDefinition in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWProjectedZoneDefinition_swigregister(RWStepDimTol_RWProjectedZoneDefinition)

class RWStepDimTol_RWRoundnessTolerance(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWRoundnessTolerance_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWRoundnessTolerance(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads roundnesstolerance.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_RoundnessTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWRoundnessTolerance_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_RoundnessTolerance
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWRoundnessTolerance_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes roundnesstolerance.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_RoundnessTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWRoundnessTolerance_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWRoundnessTolerance

# Register RWStepDimTol_RWRoundnessTolerance in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWRoundnessTolerance_swigregister(RWStepDimTol_RWRoundnessTolerance)

class RWStepDimTol_RWRunoutZoneDefinition(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWRunoutZoneDefinition_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWRunoutZoneDefinition(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads runoutzonedefinition.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_RunoutZoneDefinition

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWRunoutZoneDefinition_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_RunoutZoneDefinition
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWRunoutZoneDefinition_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes runoutzonedefinition.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_RunoutZoneDefinition

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWRunoutZoneDefinition_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWRunoutZoneDefinition

# Register RWStepDimTol_RWRunoutZoneDefinition in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWRunoutZoneDefinition_swigregister(RWStepDimTol_RWRunoutZoneDefinition)

class RWStepDimTol_RWRunoutZoneOrientation(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWRunoutZoneOrientation_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWRunoutZoneOrientation(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads runoutzoneorientation.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_RunoutZoneOrientation

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWRunoutZoneOrientation_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes runoutzoneorientation.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_RunoutZoneOrientation

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWRunoutZoneOrientation_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWRunoutZoneOrientation

# Register RWStepDimTol_RWRunoutZoneOrientation in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWRunoutZoneOrientation_swigregister(RWStepDimTol_RWRunoutZoneOrientation)

class RWStepDimTol_RWStraightnessTolerance(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWStraightnessTolerance_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWStraightnessTolerance(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads straightnesstolerance.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_StraightnessTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWStraightnessTolerance_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_StraightnessTolerance
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWStraightnessTolerance_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes straightnesstolerance.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_StraightnessTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWStraightnessTolerance_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWStraightnessTolerance

# Register RWStepDimTol_RWStraightnessTolerance in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWStraightnessTolerance_swigregister(RWStepDimTol_RWStraightnessTolerance)

class RWStepDimTol_RWSurfaceProfileTolerance(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWSurfaceProfileTolerance_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWSurfaceProfileTolerance(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads surfaceprofiletolerance.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_SurfaceProfileTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWSurfaceProfileTolerance_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_SurfaceProfileTolerance
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWSurfaceProfileTolerance_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes surfaceprofiletolerance.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_SurfaceProfileTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWSurfaceProfileTolerance_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWSurfaceProfileTolerance

# Register RWStepDimTol_RWSurfaceProfileTolerance in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWSurfaceProfileTolerance_swigregister(RWStepDimTol_RWSurfaceProfileTolerance)

class RWStepDimTol_RWSymmetryTolerance(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWSymmetryTolerance_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWSymmetryTolerance(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads symmetrytolerance.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_SymmetryTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWSymmetryTolerance_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_SymmetryTolerance
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWSymmetryTolerance_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes symmetrytolerance.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_SymmetryTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWSymmetryTolerance_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWSymmetryTolerance

# Register RWStepDimTol_RWSymmetryTolerance in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWSymmetryTolerance_swigregister(RWStepDimTol_RWSymmetryTolerance)

class RWStepDimTol_RWToleranceZone(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWToleranceZone_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWToleranceZone(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads tolerancezone.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_ToleranceZone

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWToleranceZone_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_ToleranceZone
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWToleranceZone_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes tolerancezone.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_ToleranceZone

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWToleranceZone_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWToleranceZone

# Register RWStepDimTol_RWToleranceZone in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWToleranceZone_swigregister(RWStepDimTol_RWToleranceZone)

class RWStepDimTol_RWToleranceZoneDefinition(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWToleranceZoneDefinition_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWToleranceZoneDefinition(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads tolerancezonedefinition.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_ToleranceZoneDefinition

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWToleranceZoneDefinition_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_ToleranceZoneDefinition
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWToleranceZoneDefinition_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes tolerancezonedefinition.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_ToleranceZoneDefinition

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWToleranceZoneDefinition_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWToleranceZoneDefinition

# Register RWStepDimTol_RWToleranceZoneDefinition in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWToleranceZoneDefinition_swigregister(RWStepDimTol_RWToleranceZoneDefinition)

class RWStepDimTol_RWToleranceZoneForm(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWToleranceZoneForm_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWToleranceZoneForm(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads tolerancezoneform.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_ToleranceZoneForm

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWToleranceZoneForm_ReadStep(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes tolerancezoneform.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_ToleranceZoneForm

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWToleranceZoneForm_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWToleranceZoneForm

# Register RWStepDimTol_RWToleranceZoneForm in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWToleranceZoneForm_swigregister(RWStepDimTol_RWToleranceZoneForm)

class RWStepDimTol_RWTotalRunoutTolerance(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWTotalRunoutTolerance_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWTotalRunoutTolerance(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads totalrunouttolerance.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_TotalRunoutTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWTotalRunoutTolerance_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_TotalRunoutTolerance
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWTotalRunoutTolerance_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes totalrunouttolerance.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_TotalRunoutTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWTotalRunoutTolerance_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWTotalRunoutTolerance

# Register RWStepDimTol_RWTotalRunoutTolerance in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWTotalRunoutTolerance_swigregister(RWStepDimTol_RWTotalRunoutTolerance)

class RWStepDimTol_RWUnequallyDisposedGeometricTolerance(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _RWStepDimTol.RWStepDimTol_RWUnequallyDisposedGeometricTolerance_swiginit(self, _RWStepDimTol.new_RWStepDimTol_RWUnequallyDisposedGeometricTolerance(*args))

    def ReadStep(self, *args) -> "void":
        r"""
        Reads unequallydisposedgeometrictolerance.

        Parameters
        ----------
        data: StepData_StepReaderData
        num: int
        ach: Interface_Check
        ent: StepDimTol_UnequallyDisposedGeometricTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWUnequallyDisposedGeometricTolerance_ReadStep(self, *args)

    def Share(self, *args) -> "void":
        r"""
        Fills data for graph (shared items).

        Parameters
        ----------
        ent: StepDimTol_UnequallyDisposedGeometricTolerance
        iter: Interface_EntityIterator

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWUnequallyDisposedGeometricTolerance_Share(self, *args)

    def WriteStep(self, *args) -> "void":
        r"""
        Writes unequallydisposedgeometrictolerance.

        Parameters
        ----------
        SW: StepData_StepWriter
        ent: StepDimTol_UnequallyDisposedGeometricTolerance

        Returns
        -------
        None

        """
        return _RWStepDimTol.RWStepDimTol_RWUnequallyDisposedGeometricTolerance_WriteStep(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _RWStepDimTol.delete_RWStepDimTol_RWUnequallyDisposedGeometricTolerance

# Register RWStepDimTol_RWUnequallyDisposedGeometricTolerance in _RWStepDimTol:
_RWStepDimTol.RWStepDimTol_RWUnequallyDisposedGeometricTolerance_swigregister(RWStepDimTol_RWUnequallyDisposedGeometricTolerance)





